@@ -29,13 +29,13 @@ class Aptly(Cmd):
         self.intro = ("Aptly 2.0a1\n"
                       "Type 'help' for more information or 'quit' to exit.")
         self.options = []
-        self.known_commands = ['install', 'remove', 'prompt', 'set', 'quit']
+        self.known_commands = ['install', 'update', 'remove', 'prompt', 'set', 'quit']
+        self.commands = []
 
     def emptyline(self):
         pass
 
     def precmd(self, line):
-        commands = []
         indexes = []
 
         for command in self.known_commands:
@@ -48,14 +48,16 @@ class Aptly(Cmd):
         indexes.sort()
 
         for index in xrange(len(indexes) - 1):
-            commands.append(line[indexes[index]:indexes[index+1]].strip())
+            self.commands.append(line[indexes[index]:indexes[index+1]].strip())
 
-        if len(indexes) > 0:
-            commands.append(line[indexes[-1]:].strip())
+        if len(indexes) > 0 and line[indexes[-1]:].strip() not in self.commands:
+            self.commands.append(line[indexes[-1]:].strip())
 
-        for command in commands:
+        for command in self.commands:
             self.onecmd(command)
 
+        self.commands = []
+
         return ''
 
     def complete_install(self, text, line, start_index, end_index):
@@ -129,6 +131,17 @@ class Aptly(Cmd):
                "will prompt you for package names. \n"
                "  You may exit this prompt by using the package name 'cancel'.")
 
+    def do_update(self, line):
+        Popen(['apt-get', 'update']).communicate()
+
+    def do_upgrade(self, line):
+        # TODO: ask the user if they would like to update first
+        Popen(['apt-get', 'upgrade']).communicate()
+
+    def do_list(self, package):
+        # TODO: dpkg -L <packages> : list all files installed by packages
+        pass
+
     def do_set(self, options):
         def get_cache_directory():
             cache_dir = raw_input('Which directory would you like to use '
@@ -177,6 +190,10 @@ class Aptly(Cmd):
                     pass
 
                 self.options.append("dir::cache::archives='%s'" % options[key])
+    
+    def help_set(self):
+        print ("set miscellaneous options. Currently available options:\n"
+               "\tcache <directory>")
 
     def do_prompt(self, new_prompt):
         if new_prompt:
